@@ -1,20 +1,22 @@
 # HiQ version 1.1
 #
 # Copyright (c) 2022, Oracle and/or its affiliates.
-# Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/ 
+# Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 #
 
 __author__ = "Fuheng Wu<fuheng.wu@oralce.com>"
-__date__ = "2023-02-01"
+__date__ = "2023-03-23"
 __doc__ = "HiQ is a declarative, non-intrusive, dynamic and transparent tracking and optimization system"
-__version__ = "1.1.7"
+__version__ = "1.1.11"
 __credits__ = "Henry Wu, Ivan Davchev, Jun Qian"
 
 import sys
 
 vinfo = sys.version_info
 if vinfo.major < 3 or (vinfo.major == 3 and vinfo.minor < 8):
-    print(f"HiQ supports Python version 3.8 and higher. Your version is {vinfo.major}.{vinfo.minor}.")
+    print(
+        f"HiQ supports Python version 3.8 and higher. Your version is {vinfo.major}.{vinfo.minor}."
+    )
     sys.exit(1)
 
 from .hiq_utils import (
@@ -52,13 +54,9 @@ from .utils import (
     get_percentage_loss,
     get_time_str_with_tz,
     down_sample,
-    bfloat16_supported
-)
-from .tree import (
-    get_duration_from_hiq_string,
-    get_graph_from_string,
-    Tree
+    bfloat16_supported,
 )
+from .tree import get_duration_from_hiq_string, get_graph_from_string, Tree
 
 try:
     from .memory import (
@@ -67,13 +65,24 @@ try:
         get_memory_kb,
         get_memory_b,
         get_system_peak_memory,
-        get_system_memory_usage
+        get_system_memory_usage,
     )
 except ImportError:
     pass
 from .base import HiQLatency, HiQSimple, HiQMemory
 from .server_flask import HiQFlaskLatency, HiQFlaskMemory, HiQFlaskLatencyOtel
-from hiq.framework.fastapi import HiQFastAPILatency, HiQFastAPILatencyMixin, HiQFastAPIMemory, run_fastapi
+from hiq.framework.fastapi import (
+    HiQFastAPILatency,
+    HiQFastAPILatencyMixin,
+    HiQFastAPIMemory,
+    run_fastapi,
+)
+from hiq.framework.transformers import (
+    HiQTransformerMemory,
+    HiQTransformerLatency,
+    HiQTransformerGPUMemory,
+    HiQTransformerFullMemory,
+)
 from .constants import *
 from .ddict import *
 
@@ -90,6 +99,10 @@ __all__ = [
     "HiQFastAPILatency",
     "HiQFastAPIMemory",
     "HiQFastAPILatencyMixin",
+    "HiQTransformerLatency",
+    "HiQTransformerMemory",
+    "HiQTransformerGPUMemory",
+    "HiQTransformerFullMemory",
     "run_fastapi",
     "HiQSimple",
     "HiQMemory",
@@ -130,5 +143,5 @@ __all__ = [
     "get_average_loss",
     "get_percentage_loss",
     "get_time_str_with_tz",
-    "down_sample"
+    "down_sample",
 ]
